aboutsummaryrefslogtreecommitdiff
path: root/src/backend/replication/logical/applyparallelworker.c
diff options
context:
space:
mode:
authorHeikki Linnakangas <heikki.linnakangas@iki.fi>2025-03-05 16:22:26 +0200
committerHeikki Linnakangas <heikki.linnakangas@iki.fi>2025-03-05 16:22:26 +0200
commit635f580120b99f6df71d7c12749b22acde61c5ad (patch)
treec9426b1738ae53c81ba419aa5f2dafff0ba6be32 /src/backend/replication/logical/applyparallelworker.c
parentf4e53e10b6ce0eedeb98caa4356facb47c7bb9cb (diff)
downloadpostgresql-635f580120b99f6df71d7c12749b22acde61c5ad.tar.gz
postgresql-635f580120b99f6df71d7c12749b22acde61c5ad.zip
Rename some signal and interrupt handling functions for consistency
The usual pattern for handling a signal is that the signal handler sets a flag and calls SetLatch(MyLatch), and CHECK_FOR_INTERRUPTS() or other code that is part of a wait loop calls another function to deal with it. The naming of the functions involved was a bit inconsistent, however. CHECK_FOR_INTERRUPTS() calls ProcessInterrupts() to do the heavy-lifting, but the analogous functions in aux processes were called HandleMainLoopInterrupts(), HandleStartupProcInterrupts(), etc. Similarly, most subroutines of ProcessInterrupts() were called Process*(), but some were called Handle*(). To make things less confusing, rename all the functions that are part of the overall signal/interrupt handling system but are not executed in a signal handler to e.g. ProcessSomething(), rather than HandleSomething(). The "Process" prefix is now consistently used in the non-signal-handler functions, and the "Handle" prefix in functions that are part of signal handlers, except for some completely unrelated functions that clearly have nothing to do with signal or interrupt handling. Reviewed-by: Nathan Bossart <nathandbossart@gmail.com> Discussion: https://www.postgresql.org/message-id/8a384b26-1499-41f6-be33-64b801fb98b8@iki.fi
Diffstat (limited to 'src/backend/replication/logical/applyparallelworker.c')
-rw-r--r--src/backend/replication/logical/applyparallelworker.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/backend/replication/logical/applyparallelworker.c b/src/backend/replication/logical/applyparallelworker.c
index 268b2675caa..d25085d3515 100644
--- a/src/backend/replication/logical/applyparallelworker.c
+++ b/src/backend/replication/logical/applyparallelworker.c
@@ -983,7 +983,7 @@ ParallelApplyWorkerMain(Datum main_arg)
*
* Note: this is called within a signal handler! All we can do is set a flag
* that will cause the next CHECK_FOR_INTERRUPTS() to invoke
- * HandleParallelApplyMessages().
+ * ProcessParallelApplyMessages().
*/
void
HandleParallelApplyMessageInterrupt(void)
@@ -994,11 +994,11 @@ HandleParallelApplyMessageInterrupt(void)
}
/*
* Handle a single protocol message received from a single parallel apply
* worker.
*/
static void
-HandleParallelApplyMessage(StringInfo msg)
+ProcessParallelApplyMessage(StringInfo msg)
{
char msgtype;
@@ -1060,7 +1060,7 @@ HandleParallelApplyMessage(StringInfo msg)
* Handle any queued protocol messages received from parallel apply workers.
*/
void
-HandleParallelApplyMessages(void)
+ProcessParallelApplyMessages(void)
{
ListCell *lc;
MemoryContext oldcontext;
@@ -1083,7 +1083,7 @@ HandleParallelApplyMessages(void)
*/
if (!hpam_context) /* first time through? */
hpam_context = AllocSetContextCreate(TopMemoryContext,
- "HandleParallelApplyMessages",
+ "ProcessParallelApplyMessages",
ALLOCSET_DEFAULT_SIZES);
else
MemoryContextReset(hpam_context);
@@ -1118,7 +1118,7 @@ HandleParallelApplyMessages(void)
initStringInfo(&msg);
appendBinaryStringInfo(&msg, data, nbytes);
- HandleParallelApplyMessage(&msg);
+ ProcessParallelApplyMessage(&msg);
pfree(msg.data);
}
else
@@ -994,11 +994,11 @@ HandleParallelApplyMessageInterrupt(void)
}
/*
- * Handle a single protocol message received from a single parallel apply
+ * Process a single protocol message received from a single parallel apply
* worker.
*/